import { Component, OnInit } from '@angular/core';
import {ActivatedRoute, Router} from '@angular/router';
import {TabuMiddlewareService} from '../dao/TabuMiddlewareService';
import {GameStatus} from '../interface/gameStatus';

@Component({
  selector: 'app-overview',
  templateUrl: './overview.component.html',
  styleUrls: ['./overview.component.scss']
})
export class OverviewComponent implements OnInit {

  sessionName = '';
  gameStatus: GameStatus = {
    sessionID: -1,
    red: 0,
    blue: 0,
    redTurn: true,
    activeExplainer: false,
    activeWatchdog: false
  };

  constructor(private router: Router,
              private activatedRoute: ActivatedRoute,
              private service: TabuMiddlewareService) { }

  ngOnInit(): void {
    this.activatedRoute.paramMap.subscribe(params => {
      this.sessionName = String(params.get('sessionName'));
      this.service.getGamestatus({'spielname': this.sessionName}).then(value => {
        const status = JSON.parse(value.status);
        if (status) {
          this.gameStatus.sessionID = JSON.parse(value.sessionID);
          this.gameStatus.red = JSON.parse(value.red);
          this.gameStatus.blue = JSON.parse(value.blue);
          this.gameStatus.redTurn = JSON.parse(value.redTurn);
          this.gameStatus.activeExplainer = JSON.parse(value.activeExplainer);
          this.gameStatus.activeWatchdog = JSON.parse(value.activeWatchdog);
        }
        console.log(this.gameStatus);
      }).catch(reason => console.log(reason));
    });
  }

  startGame(): void {
    this.router.navigate([this.router.url + '/red/watchdog']);
  }
}
